==> dif-database-repository-2.3.0-sources.jar: pt/digitalis/dif/dem/managers/impl/model/IRGPDService.java <==
package pt.digitalis.dif.dem.managers.impl.model;

import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.utils.common.IBeanAttributes;
import pt.digitalis.dif.dem.managers.impl.model.dao.IDataConsentDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.DataConsent;
import pt.digitalis.dif.dem.managers.impl.model.dao.IDataConsentReviewDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.DataConsentReview;
import pt.digitalis.dif.dem.managers.impl.model.dao.IDataConsentTransDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.DataConsentTrans;
import pt.digitalis.dif.dem.managers.impl.model.dao.IUserDataConsentDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.UserDataConsent;
import pt.digitalis.dif.dem.managers.impl.model.dao.IUserDataRequestDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.UserDataRequest;
import pt.digitalis.dif.dem.managers.impl.model.dao.IUserDataRequestCommentDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.UserDataRequestComment;

/**
 * NOTE: This file is auto generated and will be overwrite in a future file generation.
 */
public interface IRGPDService {

	/**
	 * Obtains a new DataConsent DAO
	 *
	 * @return A new IDataConsentDAO
	 */
    public IDataConsentDAO getDataConsentDAO();

    /**
     * Obtains a new DataSet for the DataConsent entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<DataConsent> getDataConsentDataSet();

	/**
	 * Obtains a new DataConsentReview DAO
	 *
	 * @return A new IDataConsentReviewDAO
	 */
    public IDataConsentReviewDAO getDataConsentReviewDAO();

    /**
     * Obtains a new DataSet for the DataConsentReview entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<DataConsentReview> getDataConsentReviewDataSet();

	/**
	 * Obtains a new DataConsentTrans DAO
	 *
	 * @return A new IDataConsentTransDAO
	 */
    public IDataConsentTransDAO getDataConsentTransDAO();

    /**
     * Obtains a new DataSet for the DataConsentTrans entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<DataConsentTrans> getDataConsentTransDataSet();

	/**
	 * Obtains a new UserDataConsent DAO
	 *
	 * @return A new IUserDataConsentDAO
	 */
    public IUserDataConsentDAO getUserDataConsentDAO();

    /**
     * Obtains a new DataSet for the UserDataConsent entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<UserDataConsent> getUserDataConsentDataSet();

	/**
	 * Obtains a new UserDataRequest DAO
	 *
	 * @return A new IUserDataRequestDAO
	 */
    public IUserDataRequestDAO getUserDataRequestDAO();

    /**
     * Obtains a new DataSet for the UserDataRequest entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<UserDataRequest> getUserDataRequestDataSet();

	/**
	 * Obtains a new UserDataRequestComment DAO
	 *
	 * @return A new IUserDataRequestCommentDAO
	 */
    public IUserDataRequestCommentDAO getUserDataRequestCommentDAO();

    /**
     * Obtains a new DataSet for the UserDataRequestComment entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<UserDataRequestComment> getUserDataRequestCommentDataSet();


    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param clazz
     *            the entity class
     * @return A new IDataSet instance
     */
    public IDataSet<? extends IBeanAttributes> getDataSet(Class<? extends IBeanAttributes> clazz);

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param entityName
     *            the entity class simple name
     * @return A new IDataSet instance
     */
    public IDataSet<? extends IBeanAttributes> getDataSet(String entityName);
}

==> dif-database-repository-2.3.4-5-sources.jar: pt/digitalis/dif/dem/managers/impl/model/IRGPDService.java <==
package pt.digitalis.dif.dem.managers.impl.model;

import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.utils.common.IBeanAttributes;
import pt.digitalis.dif.dem.managers.impl.model.dao.IDataConsentDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.DataConsent;
import pt.digitalis.dif.dem.managers.impl.model.dao.IDataConsentUserDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.DataConsentUser;
import pt.digitalis.dif.dem.managers.impl.model.dao.IDataConsentReviewDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.DataConsentReview;
import pt.digitalis.dif.dem.managers.impl.model.dao.IDataConsentTransDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.DataConsentTrans;
import pt.digitalis.dif.dem.managers.impl.model.dao.IUserDataConsentDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.UserDataConsent;
import pt.digitalis.dif.dem.managers.impl.model.dao.IUserDataRequestDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.UserDataRequest;
import pt.digitalis.dif.dem.managers.impl.model.dao.IUserDataRequestCommentDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.UserDataRequestComment;

/**
 * NOTE: This file is auto generated and will be overwrite in a future file generation.
 */
public interface IRGPDService {

	/**
	 * Obtains a new DataConsent DAO
	 *
	 * @return A new IDataConsentDAO
	 */
    public IDataConsentDAO getDataConsentDAO();

    /**
     * Obtains a new DataSet for the DataConsent entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<DataConsent> getDataConsentDataSet();

	/**
	 * Obtains a new DataConsentUser DAO
	 *
	 * @return A new IDataConsentUserDAO
	 */
    public IDataConsentUserDAO getDataConsentUserDAO();

    /**
     * Obtains a new DataSet for the DataConsentUser entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<DataConsentUser> getDataConsentUserDataSet();

	/**
	 * Obtains a new DataConsentReview DAO
	 *
	 * @return A new IDataConsentReviewDAO
	 */
    public IDataConsentReviewDAO getDataConsentReviewDAO();

    /**
     * Obtains a new DataSet for the DataConsentReview entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<DataConsentReview> getDataConsentReviewDataSet();

	/**
	 * Obtains a new DataConsentTrans DAO
	 *
	 * @return A new IDataConsentTransDAO
	 */
    public IDataConsentTransDAO getDataConsentTransDAO();

    /**
     * Obtains a new DataSet for the DataConsentTrans entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<DataConsentTrans> getDataConsentTransDataSet();

	/**
	 * Obtains a new UserDataConsent DAO
	 *
	 * @return A new IUserDataConsentDAO
	 */
    public IUserDataConsentDAO getUserDataConsentDAO();

    /**
     * Obtains a new DataSet for the UserDataConsent entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<UserDataConsent> getUserDataConsentDataSet();

	/**
	 * Obtains a new UserDataRequest DAO
	 *
	 * @return A new IUserDataRequestDAO
	 */
    public IUserDataRequestDAO getUserDataRequestDAO();

    /**
     * Obtains a new DataSet for the UserDataRequest entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<UserDataRequest> getUserDataRequestDataSet();

	/**
	 * Obtains a new UserDataRequestComment DAO
	 *
	 * @return A new IUserDataRequestCommentDAO
	 */
    public IUserDataRequestCommentDAO getUserDataRequestCommentDAO();

    /**
     * Obtains a new DataSet for the UserDataRequestComment entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<UserDataRequestComment> getUserDataRequestCommentDataSet();


    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param clazz
     *            the entity class
     * @return A new IDataSet instance
     */
    public IDataSet<? extends IBeanAttributes> getDataSet(Class<? extends IBeanAttributes> clazz);

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param entityName
     *            the entity class simple name
     * @return A new IDataSet instance
     */
    public IDataSet<? extends IBeanAttributes> getDataSet(String entityName);
}
